@@ -34,6 +34,7 @@ public class Coordinates {
 
     /**
      * Create coordinates from the given latitude in longitude.
+     *
      * @param latitude latitude
      * @param longitude longitude
      * @return coordinates with the given latitude and longitude
@@ -44,6 +45,7 @@ public class Coordinates {
 
     /**
      * Latitude.
+     *
      * @return latitude (never {@code null})
      */
     public BigDecimal latitude() {
@@ -52,6 +54,7 @@ public class Coordinates {
 
     /**
      * Longitude.
+     *
      * @return longitude (never {@code null})
      */
     public BigDecimal longitude() {
@@ -73,7 +76,7 @@ public class Coordinates {
 
     @Override
     public int hashCode() {
-        return Objects.hash(latitude, longitude);
+        return Objects.hash(latitude.doubleValue(), longitude.doubleValue());
     }
 
     @Override
